@@ -209,8 +209,9 @@ class LemmaTagger(BaseTagger):
         args, kwargs = get_func_params(LemmaTagger.load, locals())
         super().load(FeatTaggerModel, *args, **kwargs)
 
-    def predict(self, corpus, with_orig=False, batch_size=BATCH_SIZE,
-                split=None, clone_ds=False, save_to=None, log_file=LOG_FILE):
+    def predict(self, corpus, min_cdict_coef=.99, with_orig=False,
+                batch_size=BATCH_SIZE, split=None, clone_ds=False,
+                save_to=None, log_file=LOG_FILE):
         """Predicts tags in the LEMMA field of the corpus.
 
         Args:
@@ -219,6 +220,10 @@ class LemmaTagger(BaseTagger):
         predictions. May be either a name of the file in *CoNLL-U* format or
         list/iterator of sentences in *Parsed CoNLL-U*.
 
+        **min_cdict_coef** (`float`): min coef when
+        `corpuscula.CorpusDict.predict_lemma()` method is treated as relevant.
+        If `None`, then it's not used. Default is `min_cdict_coef=.99`.
+
         **with_orig** (`bool`): if `True`, instead of only a sequence with
         predicted labels, returns a sequence of tuples where the first element
         is a sentence with predicted labels and the second element is the
@@ -249,6 +254,7 @@ class LemmaTagger(BaseTagger):
         assert not with_orig or save_to is None, \
                'ERROR: `with_orig` can be True only if save_to is None'
         args, kwargs = get_func_params(LemmaTagger.predict, locals())
+        del kwargs['min_cdict_coef']
         kwargs['save_to'] = None
 
         cdict = self._cdict
@@ -258,11 +264,15 @@ class LemmaTagger(BaseTagger):
 
         def apply_editops(str_from, upos, ops_t, isfirst):
             if str_from and ops_t not in [None, (None,)]:
-                str_from_, coef = \
-                    cdict.predict_lemma(str_from, upos, isfirst=isfirst)
-                if coef >= .9:
-                    str_from = str_from_
-                else:
+                str_from_ = None
+                if min_cdict_coef is not None:
+                    str_from_, coef = \
+                        cdict.predict_lemma(str_from, upos, isfirst=isfirst)
+                    if coef >= min_cdict_coef:
+                        str_from = str_from_
+                    else:
+                        str_from_ = None
+                if str_from_ is None:
                     try:
                         ops_p, ops_s, ops_c = ops_t
                         str_from_ = ''.join(reversed(
@@ -314,8 +324,9 @@ class LemmaTagger(BaseTagger):
             corpus = self._get_corpus(save_to, asis=True, log_file=log_file)
         return corpus
 
-    def evaluate(self, gold, test=None, batch_size=BATCH_SIZE, split=None,
-                 clone_ds=False, log_file=LOG_FILE):
+    def evaluate(self, gold, test=None, min_cdict_coef=.99,
+                 batch_size=BATCH_SIZE, split=None, clone_ds=False,
+                 log_file=LOG_FILE):
         """Evaluate the tagger model.
 
         Args:
@@ -328,6 +339,10 @@ class LemmaTagger(BaseTagger):
         `None`, the **gold** corpus will be retagged on-the-fly, and the
         result will be used as **test**.
 
+        **min_cdict_coef** (`float`): min coef when
+        `corpuscula.CorpusDict.predict_lemma()` method is treated as relevant.
+        If `None`, then it's not used. Default is `min_cdict_coef=.99`.
+
         **batch_size** (`int`): number of sentences per batch. Default
         `batch_size=64`.
 
@@ -345,7 +360,9 @@ class LemmaTagger(BaseTagger):
         The method prints metrics and returns evaluation accuracy.
         """
         args, kwargs = get_func_params(LemmaTagger.evaluate, locals())
-        return super().evaluate(self._field, *args, **kwargs)
+        del kwargs['min_cdict_coef']
+        return super().evaluate(self._field, *args, **kwargs,
+                                min_cdict_coef=min_cdict_coef)
 
     def train(self, save_as,
               device=None, epochs=None, min_epochs=0, bad_epochs=5,
